@@ -587,8 +587,8 @@ show_config (ECalendarPreferences *prefs)
 static ECalConfigItem eccp_items[] = {
 	{ E_CONFIG_BOOK,          (gchar *) "",                             (gchar *) "toplevel-notebook", calendar_preferences_get_config_widget },
 	{ E_CONFIG_PAGE,          (gchar *) "00.general",                   (gchar *) "general",           calendar_preferences_get_config_widget },
-	{ E_CONFIG_SECTION_TABLE, (gchar *) "00.general/00.time",           (gchar *) "time",              calendar_preferences_get_config_widget },
-	{ E_CONFIG_SECTION_TABLE, (gchar *) "00.general/10.workWeek",       (gchar *) "workWeek",          calendar_preferences_get_config_widget },
+	{ E_CONFIG_SECTION_GRID,  (gchar *) "00.general/00.time",           (gchar *) "time",              calendar_preferences_get_config_widget },
+	{ E_CONFIG_SECTION_GRID,  (gchar *) "00.general/10.workWeek",       (gchar *) "workWeek",          calendar_preferences_get_config_widget },
 	{ E_CONFIG_SECTION,       (gchar *) "00.general/20.alerts",         (gchar *) "alerts",            calendar_preferences_get_config_widget },
 	{ E_CONFIG_PAGE,          (gchar *) "10.display",                   (gchar *) "display",           calendar_preferences_get_config_widget },
 	{ E_CONFIG_SECTION,       (gchar *) "10.display/00.general",        (gchar *) "displayGeneral",    calendar_preferences_get_config_widget },
@@ -646,7 +646,7 @@ calendar_preferences_add_itip_formatter_page (EShell *shell,
 	str = g_strdup_printf ("<span weight=\"bold\">%s</span>", _("General"));
 	gtk_label_set_markup (GTK_LABEL (frame_label), str);
 	g_free (str);
-	gtk_misc_set_alignment (GTK_MISC (frame_label), 0.0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (frame_label), 0);
 	gtk_box_pack_start (GTK_BOX (frame), frame_label, FALSE, FALSE, 0);
 
 	/* Indent/padding */
@@ -709,7 +709,7 @@ calendar_preferences_add_itip_formatter_page (EShell *shell,
 	str = g_strdup_printf ("<span weight=\"bold\">%s</span>", _("Conflict Search"));
 	gtk_label_set_markup (GTK_LABEL (frame_label), str);
 	g_free (str);
-	gtk_misc_set_alignment (GTK_MISC (frame_label), 0.0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (frame_label), 0);
 	gtk_box_pack_start (GTK_BOX (frame), frame_label, FALSE, FALSE, 0);
 
 	/* Indent/padding */
@@ -722,7 +722,7 @@ calendar_preferences_add_itip_formatter_page (EShell *shell,
 
 	/* Source selector */
 	label = gtk_label_new (_("Select the calendars to search for meeting conflicts"));
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_label_set_xalign (GTK_LABEL (label), 0);
 	gtk_box_pack_start (GTK_BOX (inner_vbox), label, FALSE, FALSE, 0);
 
 	scrolledwin = gtk_scrolled_window_new (NULL, NULL);
@@ -758,7 +758,7 @@ calendar_preferences_construct (ECalendarPreferences *prefs,
 	GObject *object;
 	GtkWidget *toplevel;
 	GtkWidget *widget;
-	GtkWidget *table;
+	GtkGrid *grid;
 	GSList *l;
 
 	settings = e_util_ref_settings ("org.gnome.evolution.calendar");
@@ -1242,9 +1242,9 @@ calendar_preferences_construct (ECalendarPreferences *prefs,
 		G_SETTINGS_BIND_DEFAULT);
 
 	/* date/time format */
-	table = e_builder_get_widget (prefs->priv->builder, "datetime_format_table");
-	e_datetime_format_add_setup_widget (table, 0, "calendar", "table",  DTFormatKindDateTime, _("Ti_me and date:"));
-	e_datetime_format_add_setup_widget (table, 1, "calendar", "table",  DTFormatKindDate, _("_Date only:"));
+	grid = GTK_GRID (e_builder_get_widget (prefs->priv->builder, "datetime_format_grid"));
+	e_datetime_format_add_setup_widget (grid, 0, "calendar", "table",  DTFormatKindDateTime, _("Ti_me and date:"));
+	e_datetime_format_add_setup_widget (grid, 1, "calendar", "table",  DTFormatKindDate, _("_Date only:"));
 
 	/* Hook up and add the toplevel widget */
 
